@@ -70,7 +70,9 @@ typedef enum
 	/**< Password field */
 	G_WEBENGINE_POPUPMENU_PASSWORD       = 0x0200,
 	/**< Context menu for form controls */
-	G_WEBENGINE_POPUPMENU_FORM           = 0x0400
+	G_WEBENGINE_POPUPMENU_FORM           = 0x0400,
+	/**< Background image */
+	G_WEBENGINE_POPUPMENU_BGIMAGE        = 0x0800
 } GWebEnginePopupMenuType;
 
 /** GWebEngineLoadingFinishStatus.
