@@ -509,6 +509,11 @@ void g_web_widget_signal_meta_refresh(GObject *engine_widget,
                                       gint refresh_time,
                                       GObject *browser_window);
 
+#define G_WEBWIDGET_ADD_SEARCH_PROVIDER "add-search-provider"
+
+gboolean g_web_widget_add_search_provider(GObject *engine_widget,
+                                          const gchar *description_url,
+                                          GObject *browser_window);
 
 #define G_WEBWIDGET_SIGNAL_CERTIFICATE_DIALOG           "certificate-dialog"
 #define G_WEBWIDGET_SIGNAL_CERTIFICATE_PASSWORD_DIALOG  "certificate-password-dialog"
